==> apache-gluten-1.5.0-incubating-src.tar.gz: incubator-gluten-1.5.0/gluten-flink/runtime/src/main/java/org/apache/gluten/util/ReflectUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.gluten.util;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

public class ReflectUtils {

  public static Object getObjectField(Class<?> clazz, Object obj, String fieldName) {
    try {
      Field f = clazz.getDeclaredField(fieldName);
      f.setAccessible(true);
      return f.get(obj);
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
  }

  public static Object invokeObjectMethod(
      Class<?> clazz, Object obj, String methodName, Class<?>[] paramTypes, Object[] paramValues) {
    try {
      Method m = clazz.getDeclaredMethod(methodName, paramTypes);
      m.setAccessible(true);
      return m.invoke(obj, paramValues);
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
  }
}

==> apache-gluten-1.6.0-incubating-src.tar.gz: incubator-gluten-1.6.0/gluten-flink/runtime/src/main/java/org/apache/gluten/util/ReflectUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.gluten.util;

import org.apache.flink.util.FlinkRuntimeException;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

public class ReflectUtils {

  public static Object getObjectField(Class<?> clazz, Object obj, String fieldName) {
    try {
      Field f = clazz.getDeclaredField(fieldName);
      f.setAccessible(true);
      return f.get(obj);
    } catch (Exception e) {
      throw new FlinkRuntimeException(e);
    }
  }

  public static Object getObjectField(String className, Object obj, String fieldName) {
    try {
      Class<?> clazz = Class.forName(className);
      return getObjectField(clazz, obj, fieldName);
    } catch (ClassNotFoundException e) {
      throw new FlinkRuntimeException(e);
    }
  }

  public static Object invokeObjectMethod(
      Class<?> clazz, Object obj, String methodName, Class<?>[] paramTypes, Object[] paramValues) {
    try {
      Method m = clazz.getDeclaredMethod(methodName, paramTypes);
      m.setAccessible(true);
      return m.invoke(obj, paramValues);
    } catch (Exception e) {
      throw new FlinkRuntimeException(e);
    }
  }
}
